@@ -1,6 +1,7 @@
 from __future__ import absolute_import, division
 from .auto import tqdm as tqdm_auto
 from copy import copy
+from functools import partial
 try:
     import keras
 except ImportError as e:
@@ -28,7 +29,7 @@ class TqdmCallback(keras.callbacks.Callback):
         return callback
 
     def __init__(self, epochs=None, data_size=None, batch_size=None, verbose=1,
-                 tqdm_class=tqdm_auto):
+                 tqdm_class=tqdm_auto, **tqdm_kwargs):
         """
         Parameters
         ----------
@@ -43,7 +44,11 @@ class TqdmCallback(keras.callbacks.Callback):
             are given.
         tqdm_class : optional
             `tqdm` class to use for bars [default: `tqdm.auto.tqdm`].
+        tqdm_kwargs  : optional
+            Any other arguments used for all bars.
         """
+        if tqdm_kwargs:
+            tqdm_class = partial(tqdm_class, **tqdm_kwargs)
         self.tqdm_class = tqdm_class
         self.epoch_bar = tqdm_class(total=epochs, unit='epoch')
         self.on_epoch_end = self.bar2callback(self.epoch_bar)
@@ -53,11 +58,9 @@ class TqdmCallback(keras.callbacks.Callback):
             self.batches = batches = None
         self.verbose = verbose
         if verbose == 1:
-            self.batch_bar = tqdm_class(total=batches, unit='batch',
-                                        leave=False)
+            self.batch_bar = tqdm_class(total=batches, unit='batch', leave=False)
             self.on_batch_end = self.bar2callback(
-                self.batch_bar,
-                pop=['batch', 'size'],
+                self.batch_bar, pop=['batch', 'size'],
                 delta=lambda logs: logs.get('size', 1))
 
     def on_train_begin(self, *_, **__):
@@ -78,8 +81,7 @@ class TqdmCallback(keras.callbacks.Callback):
                     total=total, unit='batch', leave=True,
                     unit_scale=1 / (params('batch_size', 1) or 1))
                 self.on_batch_end = self.bar2callback(
-                    self.batch_bar,
-                    pop=['batch', 'size'],
+                    self.batch_bar, pop=['batch', 'size'],
                     delta=lambda logs: logs.get('size', 1))
             elif self.verbose == 1:
                 self.batch_bar.unit_scale = 1 / (params('batch_size', 1) or 1)
@@ -92,6 +94,17 @@ class TqdmCallback(keras.callbacks.Callback):
             self.batch_bar.close()
         self.epoch_bar.close()
 
+    def display(self):
+        """displays in the current cell in Notebooks"""
+        container = getattr(self.epoch_bar, 'container', None)
+        if container is None:
+            return
+        from .notebook import display
+        display(container)
+        batch_bar = getattr(self, 'batch_bar', None)
+        if batch_bar is not None:
+            display(batch_bar.container)
+
     @staticmethod
     def _implements_train_batch_hooks():
         return True
